==> Pyrogram-0.12.0-py3-none-any.whl: pyrogram/api/types/message_action_chat_joined_by_link.py <==
# Pyrogram - Telegram MTProto API Client Library for Python
# Copyright (C) 2017-2019 Dan Tès <https://github.com/delivrance>
#
# This file is part of Pyrogram.
#
# Pyrogram is free software: you can redistribute it and/or modify
# it under the terms of the GNU Lesser General Public License as published
# by the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# Pyrogram is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Lesser General Public License for more details.
#
# You should have received a copy of the GNU Lesser General Public License
# along with Pyrogram.  If not, see <http://www.gnu.org/licenses/>.

from io import BytesIO

from pyrogram.api.core import *


class MessageActionChatJoinedByLink(Object):
    """Attributes:
        ID: ``0xf89cf5e8``

    Args:
        inviter_id: ``int`` ``32-bit``
    """

    __slots__ = ["inviter_id"]

    ID = 0xf89cf5e8
    QUALNAME = "MessageActionChatJoinedByLink"

    def __init__(self, *, inviter_id: int):
        self.inviter_id = inviter_id  # int

    @staticmethod
    def read(b: BytesIO, *args) -> "MessageActionChatJoinedByLink":
        # No flags
        
        inviter_id = Int.read(b)
        
        return MessageActionChatJoinedByLink(inviter_id=inviter_id)

    def write(self) -> bytes:
        b = BytesIO()
        b.write(Int(self.ID, False))

        # No flags
        
        b.write(Int(self.inviter_id))
        
        return b.getvalue()

==> Pyrogram-0.13.0-py3-none-any.whl: pyrogram/api/types/message_action_chat_joined_by_link.py <==
# Pyrogram - Telegram MTProto API Client Library for Python
# Copyright (C) 2017-2019 Dan Tès <https://github.com/delivrance>
#
# This file is part of Pyrogram.
#
# Pyrogram is free software: you can redistribute it and/or modify
# it under the terms of the GNU Lesser General Public License as published
# by the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# Pyrogram is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Lesser General Public License for more details.
#
# You should have received a copy of the GNU Lesser General Public License
# along with Pyrogram.  If not, see <http://www.gnu.org/licenses/>.

from io import BytesIO

from pyrogram.api.core import *


class MessageActionChatJoinedByLink(Object):
    """Attributes:
        ID: ``0xf89cf5e8``

    Parameters:
        inviter_id: ``int`` ``32-bit``
    """

    __slots__ = ["inviter_id"]

    ID = 0xf89cf5e8
    QUALNAME = "types.MessageActionChatJoinedByLink"

    def __init__(self, *, inviter_id: int):
        self.inviter_id = inviter_id  # int

    @staticmethod
    def read(b: BytesIO, *args) -> "MessageActionChatJoinedByLink":
        # No flags
        
        inviter_id = Int.read(b)
        
        return MessageActionChatJoinedByLink(inviter_id=inviter_id)

    def write(self) -> bytes:
        b = BytesIO()
        b.write(Int(self.ID, False))

        # No flags
        
        b.write(Int(self.inviter_id))
        
        return b.getvalue()
